#
# spec file for package timidity
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

Name:           timidity
Summary:        Software Synthesizer and MIDI Player
License:        GPL-2.0-or-later
Group:          Productivity/Multimedia/Sound/Midi
Version:        2.15.0
Release:        3.10
URL:            http://timidity.sourceforge.net/
%define my_provides /tmp/my-provides
BuildRequires:  alsa-devel
BuildRequires:  automake
BuildRequires:  flac-devel
BuildRequires:  gtk2-devel
BuildRequires:  libao-devel
BuildRequires:  libjack-devel
BuildRequires:  libogg-devel
BuildRequires:  libvorbis-devel
BuildRequires:  ncurses-devel
BuildRequires:  slang-devel
BuildRequires:  speex-devel
BuildRequires:  update-desktop-files
BuildRequires:  xaw3d
BuildRequires:  xorg-x11
Recommends:     fluid-soundfont-gm fluid-soundfont-gs
BuildRequires:  fdupes
BuildRequires:  xaw3d-devel
BuildRequires:  pkgconfig(systemd)
%{?systemd_ordering}
PreReq:         %fillup_prereq
Source:         TiMidity++-%{version}.tar.xz
Source1:        timidity-patches.tar.bz2
Source2:        %name.desktop
Source3:        timidity.png
Source4:        timidity.cfg
Source5:        %{name}.service
Source6:        %{name}.sysconf
Source7:        README.SUSE
Patch2:         0002-Fix-alsaseq-polling-at-idle-time.patch
Patch100:       timidity-no_date.patch
Patch101:       timidity-add_fluid_cfgs.patch
Patch200:       timidity-readmidi-zero-division-fix.patch
Patch201:       timidity-resample-frac-overflow-fix.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
TiMidity plays MIDI files without external MIDI instruments and
converts MIDI files to WAV using GUS/patch and SoundFont for voice
data.


%prep
%setup -q -n TiMidity++-%{version} -a 1
%patch2 -p1
%patch100
%patch101
%patch200 -p1
%patch201 -p1
for f in ./utils/bitset.c ./utils/bitset.h ./utils/nkflib.c; do
	iconv -f EUC-JISX0213 -t UTF-8 $f > $f.utf8 && mv $f.utf8 $f
done

%build
# disable LTO for avoiding segfaults with ALSA backend (boo#1149461)
%define _lto_cflags %{nil}
echo >> autoconf/arts.m4
autoreconf --force --install
%configure \
	--enable-dynamic=ncurses,emacs,slang,vt100,xskin,gtk,alsaseq,server \
	--enable-audio=alsa,oss,vorbis,jack,ao,flac,speex \
	--with-default-output=alsa \
	--enable-network \
	--enable-spectrogram \
	--enable-wrd \
	--with-module-dir=%{_libdir}/timidity \
	--with-default-path=/etc
make %{?_smp_mflags} WISH=tclsh CFLAGS="$RPM_OPT_FLAGS"

%install
%makeinstall WISH=tclsh
mkdir -p $RPM_BUILD_ROOT%{_datadir}/X11/app-defaults/
cp interface/TiMidity.ad $RPM_BUILD_ROOT/usr/share/X11/app-defaults/TiMidity
# for japanese locale
# UTF-8 version
mkdir -p $RPM_BUILD_ROOT%{_datadir}/X11/{ja,ja_JP.UTF-8,ja_JP.eucJP,ja_JP.ujis}/app-defaults
iconv -feuc-jp -tutf-8 interface/TiMidity-uj.ad > $RPM_BUILD_ROOT%{_datadir}/X11/ja/app-defaults/TiMidity
ln -s ../../ja/app-defaults/TiMidity $RPM_BUILD_ROOT%{_datadir}/X11/ja_JP.UTF-8/app-defaults/TiMidity
# EUC-jp version
cp interface/TiMidity-uj.ad $RPM_BUILD_ROOT%{_datadir}/X11/ja_JP.eucJP/app-defaults/TiMidity
ln -s ../../ja_JP.eucJP/app-defaults/TiMidity $RPM_BUILD_ROOT%{_datadir}/X11/ja_JP.ujis/app-defaults/TiMidity
# copy documents
mkdir -p $RPM_BUILD_ROOT%{_docdir}/%{name}
cp AUTHORS ChangeLog* NEWS README TODO \
  $RPM_BUILD_ROOT%{_docdir}/%{name}
cp %{SOURCE7} $RPM_BUILD_ROOT%{_docdir}/%{name}
for i in *.ja; do
  iconv -f euc-jp -t utf8 $i > $RPM_BUILD_ROOT%{_docdir}/%{name}/$i
done
mkdir -p $RPM_BUILD_ROOT%{_docdir}/%{name}/en
(cd doc/C
  for i in * ; do
    case $i in
    Makefile*|*.[1-9])
      ;;
    *)
      cp $i $RPM_BUILD_ROOT%{_docdir}/%{name}/en
      ;;
    esac
  done
)
mkdir -p $RPM_BUILD_ROOT%{_docdir}/%{name}/ja_JP
(cd doc/ja_JP.eucJP
  for i in * ; do
    case $i in
    Makefile*|*.[1-9])
      ;;
    *)
      iconv -f euc-jp -t utf8 $i > $RPM_BUILD_ROOT%{_docdir}/%{name}/ja_JP/$i
      ;;
    esac
  done
)
# copy sample patches and config file
mkdir -p $RPM_BUILD_ROOT%{_datadir}/timidity
cp -a timidity-patches/* $RPM_BUILD_ROOT%{_datadir}/timidity
mkdir -p $RPM_BUILD_ROOT%{_datadir}/emacs/site-lisp
mkdir -p $RPM_BUILD_ROOT%{_datadir}/xemacs/site-lisp/lisp
cp interface/timidity.el $RPM_BUILD_ROOT%{_datadir}/emacs/site-lisp
cp interface/timidity.el $RPM_BUILD_ROOT%{_datadir}/xemacs/site-lisp/lisp
%suse_update_desktop_file -i -u %name AudioVideo Midi
mkdir -p $RPM_BUILD_ROOT%{_datadir}/pixmaps
cp %{SOURCE3} $RPM_BUILD_ROOT%{_datadir}/pixmaps
mkdir -p $RPM_BUILD_ROOT/etc
install -c -m 644 %{SOURCE4} $RPM_BUILD_ROOT/etc

# boot scripts
#
%__install -m 644 -D %{S:6} %{buildroot}%{_fillupdir}/sysconfig.timidity
%__install -Dm 644 %{S:5} %{buildroot}%{_unitdir}/%{name}.service
%__install -d %{buildroot}%{_sbindir}
ln -s /usr/sbin/service %{buildroot}%{_sbindir}/rc%{name}

# exclude plugins from the provide-list
cat << EOF > %{my_provides}
grep -v $RPM_BUILD_ROOT%{_libdir}/timidity | %{__find_provides}
EOF
chmod 755 %{my_provides}
%define __find_provides %{my_provides}
%fdupes -s %{buildroot}

%pre
%service_add_pre %{name}.service

%post
%fillup_only
%service_add_post %{name}.service

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.service

%files
%defattr(-,root,root)
%license COPYING
%doc %{_docdir}/timidity
%{_libdir}/timidity
%{_datadir}/timidity
%config(noreplace) %{_datadir}/timidity/timidity.cfg
%{_bindir}/timidity
%{_datadir}/applications/*.desktop
%{_datadir}/pixmaps/*.png
%config /etc/timidity.cfg
%{_mandir}/man*/*
%{_datadir}/X11/app-defaults/TiMidity
%{_datadir}/X11/ja*
%{_datadir}/emacs
%{_datadir}/xemacs
%{_unitdir}/timidity.service
%{_sbindir}/rctimidity
%{_fillupdir}/sysconfig.timidity

%changelog
* Thu Nov 25 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Modified:
  * timidity.service
* Mon Aug  9 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Fix install conflict between timidity and filesystem (boo#1189226)
- Use %%license macro to install COPYING
* Sat Aug 15 2020 Dirk Mueller <dmueller@suse.com>
- update to 2.15.0:
    Add support for segment play option (-G, --segment) with a great
    contribution by Yotam Medini <yotam.medini@gmail.com>.
  * Add metronome indicator in dumb interface trace mode.
  * Let libao backend set ao options via TIMIDITY_AO_OPTIONS
    environment variable.
  * Fix for CVE-2009-0179, CVE-2009-3996, CVE-2010-2546 and
    CVE-2010-2971.
  * Fix for CVE-2017-11546 (bsc#1081694)
  * Support for Tcl/Tk 8.6.
  * Improve Windows MIDI driver.
  * ...and many other bug fixes.
* Mon Feb  3 2020 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(systemd) instead of systemd: allow OBS to
  shortcut through the -mini flavors.
* Mon Sep 23 2019 tiwai@suse.de
- Disable LTO for avoiding segfaults with ALSA backend (boo#1149461)
* Tue Feb 20 2018 tiwai@suse.de
- Fix division-by-zero with malformed MIDI file (CVE-2017-11546,
  bsc#1081694):
  timidity-readmidi-zero-division-fix.patch
- Fix out-of-bound accesses in the resamplers (CVE-2017-11547,
  bsc#1081694):
  timidity-resample-frac-overflow-fix.patch
- Drop tcl/tk dependency; it's already broken with Tcl/Tk 8.6
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Wed Sep 27 2017 dimstar@opensuse.org
- Disable obsolete esd support:
  + Drop esound-devel BuildRequires.
  + Remove esd from configure's --enable-audio parameter.
* Mon Jul 21 2014 p.drouand@gmail.com
- Update to version 2.14.0 (final)
  + Add --reverb option for Freeverb parameter.
  + Add --preserve-silence option.
  + Add a "trysource" config file directive, which allows to try and
    source other config files, while continuing without error if the
    specified file is missing.
  + Support for GM2 Master Fine/Coarse Tuning, GS Master Tune and XG
    Master Tuning (4C not 27) SysEx.
  + Allow Device Numbers other than 0x10 for XG SYSTEM ON SYSEX
    events.
  + Fix multiple vulnerabilities found in GNU gzip also apply to lha,
    namely: CVE-2006-4335, CVE-2006-4337 and CVE-2006-4338.
  + Support for lzma decompression.
  + Support for ipv6.
  + Support for libpng 1.5 and newer.
  + Support for Tcl/Tk 8.5.
  + Make compatible with xaw3d v1.5, style changes.
  + Various improvements in XAW interface (see README.xaw).
  + Support for Windows Named Pipe interface.
  + ...and many other bug fixes.
- Use systemd instead of sysvinit
- Remove obsolete patches
  + 0001-Fix-possible-invalid-access-below-the-array-range.patch
  + 0003-Fix-the-faulty-check-of-parameters-in-server_c.c-con.patch
  + 0004-Add-missing-void-argument-for-function-declarations.patch
  + 0005-Add-missing-quotes-in-autoconf-utils.m4.patch
  + 0006-Add-the-lzma-decompression-support.patch
  + 0007-Fix-the-missing-return-value-in-emacs_c.c.patch
  + 0008-Fix-type-punning-in-smplfile.c.patch
  + 0009-Use-AS_HELP_STRING-to-make-the-help-output-more-read.patch
- Remove obsolete macros hacks
- Fix default parameters for server mode
- Fix wrong SUSE capitalization
- Use download Url as source
* Sat Dec  1 2012 freek@opensuse.org
- timidity as a system daemon conflicts with pulseaudio bnc#790158
  a warning is printed when timidity as a system daemon is started and
  pulsaudio is enabled. The solution is documented in README.SuSE.
* Fri Nov  9 2012 freek@opensuse.org
- Fixed init script TIM_ALSASEQPARAM -> TIM_ALSASEQPARAMS bnc#788444
- Reversed value of the two pameters in /etc/sysconfig/timidity and
  added some extra parameters as default
- Added some comment about the values of the paramters and
  two recommended package: fluid-soundfont-gm and fluid-soundfont-gs
* Wed May 30 2012 tiwai@suse.de
- Update to TiMidity++ 2.14.0-pre git version (commit 81c8d72e)
- Rebase existing patches
* Mon May 28 2012 jengelh@inai.de
- Remove redundant tags/sections from specfile
- Parallel build with %%_smp_mflags
- Disable building the Motif output plugin
  (see http://lists.opensuse.org/opensuse-factory/2012-05/msg00133.html)
* Tue Mar 27 2012 aj@suse.de
- Add buildrequire on xorg-x11 for directory ownership.
* Fri Dec  2 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Tue Sep 20 2011 idonmez@suse.com
- Fix timidity startup parameter bnc#675426
- Don't package INSTALL file
* Fri Aug 12 2011 tiwai@suse.de
- Fix inifinte loop with non-existing soundfont files
* Wed Jan 19 2011 pth@suse.de
- Fix name of fluid config files.
* Wed Jan 19 2011 pth@suse.de
- Fix init script, use pmidi to list the midi ports TiMidity has
  connected to.
* Wed Jan 19 2011 pth@suse.de
- Add an init script that sets up timidity as an alsa MIDI
  sequencer.
- Fix all implicit declarations.
- Enable FLAC/OggFLAC and speex support.
- Fix timidity to work with the changed FLAC API.
- Fix OggFLAC support.
- Properly quote arguments to AC_DEFUN
- Use AS_HELP_STRING to make the --help output more readable.
- Add _cv_ to configure variables to get them cached again.
- Fix ptr<->int casts.
- Add xz and lzma to list of decompressors.
- Convert files in utils from EUC-JISX0213 to UTF-8.
- Remove use of __DATE__ to prevent needless rebuilds.
- Recommend the FLUID soundfont packages.
- Add commented lines to source the soundfont configuration
  files.
* Fri Sep  3 2010 tiwai@suse.de
- remove arts output for FACTORY (so that libpng14 is used)
* Tue Jun 30 2009 tiwai@suse.de
- fix array subscript overflow in server_c.c (bnc#517719)
* Thu Sep 25 2008 lrupp@suse.de
- build on older distributions
- disable internal dependency generator
* Wed Apr 16 2008 tiwai@suse.de
- fix build with tcl8.5
* Tue Jan 15 2008 tiwai@suse.de
- fix app-defaults for UTF-8 japanese locale (#353816)
- fix fonts to work without 100dpi fonts
* Thu Aug  2 2007 tiwai@suse.de
- fix alsaseq polling at idle time
- clean up spec file
* Wed Jun 20 2007 tiwai@suse.de
- fix fdupes usage
- fix encoding of ja_JP documents
* Tue Jun 12 2007 tiwai@suse.de
- add missing libao support
- use fdupes to make rpmlint happy
* Fri Jun  1 2007 dmueller@suse.de
- fix buildrequires
* Wed May 23 2007 tiwai@suse.de
- fixed path in non-executable *.tcl files
* Mon Apr  2 2007 rguenther@suse.de
- add ncurses-devel BuildRequires
* Wed Jan 31 2007 tiwai@suse.de
- fix invalid array access (#240161)
- fix broken gcc4-fix patch
* Tue Aug 29 2006 ro@suse.de
- add a newline to autoconf/arts.m4 for new m4
* Thu Aug  3 2006 tiwai@suse.de
- fixed app-defaults path to /usr/share/X11.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Dec  2 2005 tiwai@suse.de
- fixed compile warning (#134737).
* Thu Oct 13 2005 tiwai@suse.de
- removed glib* from neededforbuild.
* Tue May 10 2005 meissner@suse.de
- use RPM_OPT_FLAGS. Fix problems spotted by gcc4.
* Thu Apr 14 2005 sbrabec@suse.cz
- Added audiofile-devel to neededforbuild.
* Fri Apr  8 2005 tiwai@suse.de
- fix compilation with gcc-4.0.
* Fri Jan 21 2005 tiwai@suse.de
- updated to version 2.13.2.
- link with gtk2.
* Thu Aug  5 2004 tiwai@suse.de
- updated to 2.13.0 final.
- enabled server mode again.
* Mon Mar  1 2004 tiwai@suse.de
- updated to 2.13.0-rc2 tarball.
* Fri Feb 27 2004 tiwai@suse.de
- updated to 2.13.0-rc2 (cvs version).
- build interfaces as dynamic objects.
- fixed the path of timidity.el.
* Tue Feb 17 2004 adrian@suse.de
- fix Categories
* Wed Feb 11 2004 tiwai@suse.de
- updated to version 2.13.0-rc1.
- added glib2 and glib2-devel for arts.
* Mon Jan 12 2004 adrian@suse.de
- build as user
* Fri Jan  9 2004 tiwai@suse.de
- updated to cvs 2004.01.09 version.
* Mon Nov 17 2003 tiwai@suse.de
- updated to cvs 2003.11.17 version.
  all patches have been merged.
- use /etc/timidity.cfg as the config file (bug #32486).
* Thu Sep 18 2003 tiwai@suse.de
- fixed a segfault when a non-existing drum is played.
- fixed the fallback device detection.
* Mon Sep 15 2003 tiwai@suse.de
- added desktop icon.
* Fri Sep 12 2003 tiwai@suse.de
- security fix for realtime-priority mode.
- added RT-priority and sequencer ports options.
- fixed the effect table.
- fixed the option parser.
* Mon Sep  8 2003 tiwai@suse.de
- use the absolute path in desktop file to avoid the name
  confliction.
* Thu Sep  4 2003 adrian@suse.de
- it is installed by default -> hide menu entry by default
* Wed Sep  3 2003 tiwai@suse.de
- fixed the generation of tclIndex on build system.
- clean up make install stuffs.
* Tue Sep  2 2003 tiwai@suse.de
- fixed the xaw interface bug.
- exit timidity properly when the interface is killed.
- install japanese X resource files.
* Wed Aug 27 2003 tiwai@suse.de
- improved the rendering resolution on ALSA sequencer interface.
  supporting non-stream type output devices like WAV.
- set the proper client name on ALSA sequener interface.
* Mon Aug 25 2003 tiwai@suse.de
- updated to cvs 2003.08.25.
  supporting JACK output.
- fixed neededforbuild for JACK support.
* Tue Aug 19 2003 tiwai@suse.de
- updated to cvs version 2003.08.19.
  supported long options.
- use xaw interface for desktop command.
* Fri Aug 15 2003 adrian@suse.de
- add desktop file
* Thu Jul 24 2003 tiwai@suse.de
- added tk-devel to neededforbuild.
* Wed Jul 23 2003 uli@suse.de
- no ALSA on s390*
* Tue Jul 22 2003 tiwai@suse.de
- updated to cvs 2003.07.22.
  fixed the fallback output-device.
- added aRts output support.
* Mon Jul 14 2003 sbrabec@suse.cz
- GNOME prefix change to /opt/gnome.
* Mon Jul  7 2003 tiwai@suse.de
- updated to cvs 2003.07.07.
- removed obsolete documents.
* Thu Jul  3 2003 tiwai@suse.de
- fixed the build on x86-64.
* Wed Jul  2 2003 tiwai@suse.de
- use the nightly tarball 2003.07.02 including many fixes.
* Thu Jun  5 2003 ro@suse.de
- remove unpackaged files from buildroot
* Thu Aug 29 2002 tiwai@suse.de
- fixed alsaseq interface to initialize effects (bug #18558).
* Tue Aug 20 2002 tiwai@suse.de
- fixed the declarations of variables on 64bit architectures.
* Mon Aug 12 2002 tiwai@suse.de
- updated to the patch to 20020804 version.
* Mon Aug 12 2002 schwab@suse.de
- Fix makefile.
* Mon Jul 15 2002 tiwai@suse.de
- added detection of tcl/tk 8.4.
* Wed Jul  3 2002 tiwai@suse.de
- fixed seg-fault on alsa seq interface mode.
* Mon Jul  1 2002 tiwai@suse.de
- updated to version 2.12.0-pre1b.
  alsa 0.9 patch is already included.
- added unofficial enhancement patches.
* Fri May 31 2002 ro@suse.de
- changed neededforbuild <slang> to <slang slang-devel>
* Mon May  6 2002 tiwai@suse.de
- fixed __libdir.
* Mon Apr  8 2002 ro@suse.de
- build with current automake/autoconf
* Thu Mar  7 2002 tiwai@suse.de
- open the device with non-block mode on alsa output.
* Mon Feb 18 2002 tiwai@suse.de
- fixed the path in default config file (Bug #13392).
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Tue Jan 22 2002 ttiwai@suse.de
- updated to version 2.11.3 (bug fixed version).
- added %%defattr to filelist.
* Tue Jan 15 2002 tiwai@suse.de
- updated to version 2.11.2. (bug-fixed version)
- regenerated alsa9 patch.
* Wed Jan  2 2002 tiwai@suse.de
- updated to version 2.11.1.
- removed (already integrated) patches for soundfont support.
* Mon Dec  3 2001 tiwai@suse.de
- corrected patch for ALSA 0.9.0.
* Mon Nov  5 2001 tiwai@suse.de
- updated to version 2.11.0-pre2.
- fixed build with the latest automake.
- improved lowpass filter in soundfont emulation.
* Thu Oct 25 2001 tiwai@suse.de
- fixed incorrect tuning on some soundfonts.
- added suse_update_config.
* Mon Oct  8 2001 tiwai@suse.de
- support playback of RMI file (bug #11680).
* Fri Jul 13 2001 tiwai@suse.de
- use _prefix and co.
- fixed filelist.
- fixed compile on ia64.
* Mon Apr  2 2001 uli@suse.de
- small fix for gcc >2.96
* Fri Mar 23 2001 tiwai@suse.de
- fixed typo of documents location.
* Tue Mar 20 2001 tiwai@suse.de
- updated to ver.2.10.4.
- added slang to neededforbuild.
- updated options.html.
- removed Makefile* from documents.
* Mon Mar 12 2001 tiwai@suse.de
- updated to ver.2.10.3.
- Add README.SuSE and options.html as separate files.
* Mon Dec 11 2000 tiwai@suse.de
- added a sample patchset (out of kmidi).
* Wed Nov 29 2000 tiwai@suse.de
- fixed big-endian support on alsa output device.
* Wed Nov 29 2000 ro@suse.de
- changed neededforbuild <tcld> to <tcl-devel>
* Mon Nov 20 2000 ro@suse.de
- use openmotif
* Tue Nov 14 2000 tiwai@suse.de
- Updated to 2.10.2.
* Tue Sep 26 2000 tiwai@suse.de
- Update of ALSA-0.6.0 support.
* Fri Sep  1 2000 tiwai@suse.de
- Bugfix of ALSA sequencer interface and ALSA audio output.
- Support for ALSA 0.6.0 (not enabled by build though).
* Tue Aug 15 2000 tiwai@suse.de
- update to official version 2.10.0
- small alsaseq interface bugfix
* Tue Aug  1 2000 tiwai@suse.de
- update to version 2.10.0a3 (with the latest alsaseq patch)
- add ALSA and ESD outputs
- fix tcl/tk check in configure script
* Thu May 25 2000 freitag@suse.de
- update to version 2.9.4
* Mon Feb  7 2000 freitag@suse.de
- initial version 2.8.1
